@@ -1,47 +1,63 @@
 # -*- coding: utf-8 -*-
-#
+# -----------------------------------------------------------------------------
 # Copyright © Spyder Project Contributors
+#
 # Licensed under the terms of the MIT License
+# (see spyder/__init__.py for details)
+# -----------------------------------------------------------------------------
 
 """
-Tests for arrayeditor.py
+Tests for the array editor.
 """
 
-# Stdlib imports
+# Standard library imports
 import os
+from sys import platform
+try:
+    from unittest.mock import Mock, ANY
+except ImportError:
+    from mock import Mock, ANY  # Python 2
 
 # Third party imports
 import numpy as np
 from numpy.testing import assert_array_equal
 import pytest
 from qtpy.QtCore import Qt
+from flaky import flaky
 
 # Local imports
-from spyder.widgets.variableexplorer.arrayeditor import ArrayEditor
+from spyder.widgets.variableexplorer.arrayeditor import ArrayEditor, ArrayModel
 
 
+# =============================================================================
+# Utility functions
+# =============================================================================
 def launch_arrayeditor(data, title="", xlabels=None, ylabels=None):
-    """Helper routine to launch an arrayeditor and return its result"""
+    """Helper routine to launch an arrayeditor and return its result."""
     dlg = ArrayEditor()
     assert dlg.setup_and_check(data, title, xlabels=xlabels, ylabels=ylabels)
     dlg.show()
     dlg.accept()  # trigger slot connected to OK button
     return dlg.get_value()
 
+
 def setup_arrayeditor(qbot, data, title="", xlabels=None, ylabels=None):
     """Setups an arrayeditor."""
     dlg = ArrayEditor()
-    dlg.setup_and_check(data, title, xlabels=xlabels, ylabels=ylabels)    
+    dlg.setup_and_check(data, title, xlabels=xlabels, ylabels=ylabels)
     dlg.show()
     qbot.addWidget(dlg)
     return dlg
 
-# --- Tests
-# -----------------------------------------------------------------------------
-def test_type_errors(qtbot):
-    """Verify that we don't get a TypeError for certain structured arrays.
 
-    Fixes issue 5254.
+# =============================================================================
+# Tests
+# =============================================================================
+def test_type_errors(qtbot):
+    """
+    Verify that we don't get a TypeError for certain structured arrays.
+
+    Fixes issue #5254.
     """
     arr = np.ones(2, dtype=[('X', 'f8', (2,10)), ('S', 'S10')])
     dlg = setup_arrayeditor(qtbot, arr)
@@ -132,6 +148,13 @@ def test_arrayeditor_with_3d_array(qtbot):
     assert_array_equal(arr, launch_arrayeditor(arr, "3D array"))
 
 
+def test_arrayeditor_with_empty_3d_array(qtbot):
+    arr = np.zeros((0, 10, 2))
+    assert_array_equal(arr, launch_arrayeditor(arr, "3D array"))
+    arra = np.zeros((1, 10, 2))
+    assert_array_equal(arr, launch_arrayeditor(arr, "3D array"))
+
+
 def test_arrayeditor_edit_1d_array(qtbot):
     exp_arr = np.array([1, 0, 2, 3, 4])
     arr = np.arange(0, 5)
@@ -172,5 +195,80 @@ def test_arrayeditor_edit_2d_array(qtbot):
     assert np.sum(diff_arr != dlg.get_value()) == 2
 
 
+def test_arraymodel_set_data_overflow(monkeypatch):
+    """
+    Test that entry of an overflowing integer is caught and handled properly.
+
+    Unit regression test for #6114 .
+    """
+    MockQMessageBox = Mock()
+    attr_to_patch = 'spyder.widgets.variableexplorer.arrayeditor.QMessageBox'
+    monkeypatch.setattr(attr_to_patch, MockQMessageBox)
+
+    # Numpy doesn't raise OverflowError on Linux for ints smaller than 64 bits
+    if platform.startswith('linux'):
+        int32_bit_exponent = 66
+    else:
+        int32_bit_exponent = 34
+    test_parameters = [(1, np.int32, int32_bit_exponent), (2, np.int64, 66)]
+
+    for idx, int_type, bit_exponent in test_parameters:
+        test_array = np.array([[5], [6], [7], [3], [4]], dtype=int_type)
+        model = ArrayModel(test_array.copy())
+        index = model.createIndex(0, 2)
+        assert not model.setData(index, str(int(2 ** bit_exponent)))
+        MockQMessageBox.critical.assert_called_with(ANY, "Error", ANY)
+        assert MockQMessageBox.critical.call_count == idx
+        assert np.sum(test_array == model._data) == len(test_array)
+
+
+@flaky(max_runs=3)
+def test_arrayeditor_edit_overflow(qtbot, monkeypatch):
+    """
+    Test that entry of an overflowing integer is caught and handled properly.
+
+    Integration regression test for #6114 .
+    """
+    MockQMessageBox = Mock()
+    attr_to_patch = 'spyder.widgets.variableexplorer.arrayeditor.QMessageBox'
+    monkeypatch.setattr(attr_to_patch, MockQMessageBox)
+
+    # Numpy doesn't raise the OverflowError for ints smaller than 64 bits
+    if platform.startswith('linux'):
+        int32_bit_exponent = 66
+    else:
+        int32_bit_exponent = 34
+    test_parameters = [(1, np.int32, int32_bit_exponent), (2, np.int64, 66)]
+    expected_array = np.array([5, 6, 7, 3, 4])
+
+    for idx, int_type, bit_exponent in test_parameters:
+        test_array = np.arange(0, 5).astype(int_type)
+        dialog = ArrayEditor()
+        assert dialog.setup_and_check(test_array, '1D array',
+                                      xlabels=None, ylabels=None)
+        dialog.show()
+        qtbot.waitForWindowShown(dialog)
+        view = dialog.arraywidget.view
+
+        qtbot.keyClick(view, Qt.Key_Down)
+        qtbot.keyClick(view, Qt.Key_Up)
+        qtbot.keyClicks(view, '5')
+        qtbot.keyClick(view, Qt.Key_Down)
+        qtbot.keyClick(view, Qt.Key_Space)
+        qtbot.keyClicks(view.focusWidget(), str(int(2 ** bit_exponent)))
+        qtbot.keyClick(view.focusWidget(), Qt.Key_Down)
+        MockQMessageBox.critical.assert_called_with(ANY, "Error", ANY)
+        assert MockQMessageBox.critical.call_count == idx
+        qtbot.keyClicks(view, '7')
+        qtbot.keyClick(view, Qt.Key_Up)
+        qtbot.keyClicks(view, '6')
+        qtbot.keyClick(view, Qt.Key_Down)
+        qtbot.wait(200)
+        dialog.accept()
+        qtbot.wait(500)
+        assert np.sum(expected_array ==
+                      dialog.get_value()) == len(expected_array)
+
+
 if __name__ == "__main__":
     pytest.main()
